Structs
map_vec::Setis a data structure with aSet-like API but based on aVec. It’s primarily useful when you care about constant factors or prefer determinism to speed. Please refer to the docs forSetfor details and examples of the Set API.
map_vec::Set is a data structure with a Set-like API but based on a Vec.
It’s primarily useful when you care about constant factors or prefer determinism to speed.
Please refer to the docs for Set for details and examples of the Set API.